@@ -74,7 +74,7 @@ class MainWindow(QtGui.QMainWindow):
     def about(self):
         QtGui.QMessageBox.about(self, "Information\n",
                  "With this tool you can change\n"
-                 "the periode of time, your device\n"
+                 "the period of time, your device\n"
                  "checks for updates.\n"
                  "Value 0 = Updates off!")
         
